@@ -3,6 +3,7 @@
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
 // Copyright (C) 2000 Universitaet Passau, Germany.
+// Copyright (C) 2001, 2003 Free Software Foundation, Inc.
 // Written by Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
@@ -10,7 +11,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,8 +20,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -35,7 +35,7 @@
 #include <X11/Xlib.h>
 
 #include "version.h"
-#include "OnOff.h"
+#include "x11/OnOff.h"
 #include "BindingS.h"
 
 // The DDD application class name
@@ -71,6 +71,8 @@
 #define XtNgdbSettings           "gdbSettings"
 #define XtNjdbInitCommands       "jdbInitCommands"
 #define XtNjdbSettings           "jdbSettings"
+#define XtNmakeInitCommands      "makeInitCommands"
+#define XtNmakeSettings          "makeSettings"
 #define XtNperlInitCommands      "perlInitCommands"
 #define XtNperlSettings          "perlSettings"
 #define XtNpydbInitCommands      "pydbInitCommands"
@@ -115,8 +117,6 @@
 #define XtNindentSource          "indentSource"
 #define XtNindentCode            "indentCode"
 #define XtCIndent                "Indent"
-#define XtNlineNumberWidth       "lineNumberWidth"
-#define XtCLineNumberWidth       "LineNumberWidth"
 #define XtNsourceEditing         "sourceEditing"
 #define XtCSourceEditing         "SourceEditing"
 #define XtNlineBufferedConsole   "lineBufferredConsole"
@@ -128,6 +128,7 @@
 #define XtNdbxDisplayShortcuts   "dbxDisplayShortcuts"
 #define XtNgdbDisplayShortcuts   "gdbDisplayShortcuts"
 #define XtNjdbDisplayShortcuts   "jdbDisplayShortcuts"
+#define XtNmakeDisplayShortcuts  "makeDisplayShortcuts"
 #define XtNperlDisplayShortcuts  "perlDisplayShortcuts"
 #define XtNpydbDisplayShortcuts  "pydbDisplayShortcuts"
 #define XtNxdbDisplayShortcuts   "xdbDisplayShortcuts"
@@ -146,6 +147,10 @@
 #define XtNseparateSourceWindow  "separateSourceWindow"
 #define XtNseparateExecWindow    "separateExecWindow"
 #define XtCSeparate              "Separate"
+#define XtNsideBySideWindows     "sideBySideWindows"
+#define XtCSideBySide            "SideBySide"
+#define XtNdarkMode              "darkMode"
+#define XtCDarkMode              "DarkMode"
 #define XtNopenDataWindow        "openDataWindow"
 #define XtNopenSourceWindow      "openSourceWindow"
 #define XtNopenDebuggerConsole   "openDebuggerConsole"
@@ -214,10 +219,6 @@
 #define XtCUncompressCommand     "UncompressCommand"
 #define XtNpsCommand             "psCommand"
 #define XtCPsCommand             "PsCommand"
-#define XtNwwwPage               "wwwPage"
-#define XtCWWWPage               "WWWPage"
-#define XtNwwwCommand            "wwwCommand"
-#define XtCWWWCommand            "WWWCommand"
 #define XtNshowInvocation        "showInvocation"
 #define XtCShowInvocation        "ShowInvocation"
 #define XtNshowVersion           "showVersion"
@@ -417,8 +418,6 @@
 #define XtCDebugCoreDumps        "DebugCoreDumps"
 #define XtNmaintenance       	 "maintenance"
 #define XtCMaintenance       	 "Maintenance"
-#define XtNlessTifVersion        "lessTifVersion"
-#define XtCLessTifVersion        "LessTifVersion"
 #define XtNdddinitVersion        "dddinitVersion"
 #define XtNappDefaultsVersion    "appDefaultsVersion"
 #define XtCVersion               "Version"
@@ -442,6 +441,8 @@ struct AppData {
     const _XtString    gdb_settings;
     const _XtString    jdb_init_commands;
     const _XtString    jdb_settings;
+    const _XtString    make_init_commands;
+    const _XtString    make_settings;
     const _XtString    perl_init_commands;
     const _XtString    perl_settings;
     const _XtString    pydb_init_commands;
@@ -470,7 +471,6 @@ struct AppData {
     Cardinal  indent_source;
     Cardinal  indent_script;
     Cardinal  indent_code;
-    Cardinal  line_number_width;
     Boolean   source_editing;
     Boolean   line_buffered_console;
     OnOff     console_has_focus;
@@ -481,6 +481,7 @@ struct AppData {
     const _XtString    jdb_display_shortcuts;
     const _XtString    perl_display_shortcuts;
     const _XtString    pydb_display_shortcuts;
+    const _XtString    make_display_shortcuts;
     const _XtString    xdb_display_shortcuts;
     const _XtString    console_buttons;
     const _XtString    source_buttons;
@@ -492,6 +493,8 @@ struct AppData {
     Boolean   separate_data_window;
     Boolean   separate_source_window;
     Boolean   separate_exec_window;
+    Boolean   side_by_side_windows;
+    Boolean   dark_mode;
     Boolean   data_window;
     Boolean   source_window;
     Boolean   debugger_console;
@@ -525,10 +528,7 @@ struct AppData {
     const _XtString    list_source_command;
     const _XtString    list_core_command;
     const _XtString    list_dir_command;
-    const _XtString    uncompress_command;
     const _XtString    ps_command;
-    const _XtString    www_page;
-    const _XtString    www_command;
     Boolean   show_invocation;
     Boolean   show_version;
     Boolean   show_configuration;
@@ -639,7 +639,6 @@ struct AppData {
     Boolean   maintenance;
     Boolean   dump_core;
     Boolean   debug_core_dumps;
-    int       lesstif_version;
     const _XtString    dddinit_version;
     const _XtString    app_defaults_version;
 };
