@@ -2,6 +2,7 @@
 // Breakpoint handler
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 2003 Free Software Foundation, Inc.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>.
 // 
 // This file is part of DDD.
@@ -9,7 +10,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,8 +19,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -33,13 +33,14 @@
 // A `BreakPoint' stores information about an existing debugger breakpoint.
 //-----------------------------------------------------------------------------
 
+#include <vector>
+
 #include <X11/Intrinsic.h>
 
 // Misc includes
-#include "strclass.h"
-#include "bool.h"
+#include "base/strclass.h"
+#include "base/bool.h"
 #include "GDBAgent.h"
-#include "StringA.h"
 
 // Breakpoint type, respectively:
 //  Breakpoint
@@ -71,20 +72,48 @@ enum BPDispo {
     BPDIS			// Disable (`enable once' in GDB)
 };
 
+class BreakPoint;
+
+class BreakPointLocn {
+    string  myfile_name;	// File name
+    int     myline_nr;		// Line number
+    string  myaddress;		// Address in memory
+    string  myfunc;		// Function name
+    Widget  mysource_glyph;	// Associated glyph in source
+    Widget  mycode_glyph;	// Associated glyph in code
+public:
+    BreakPointLocn():
+	myfile_name(""),
+	myline_nr(0),
+	myaddress(""),
+	myfunc(""),
+	mysource_glyph(0),
+	mycode_glyph(0)
+    {
+    }
+    // Breakpoint position
+    const string& file_name() const { return myfile_name; }
+    int line_nr() const             { return myline_nr; }
+    const string& address() const   { return myaddress; }
+    string pos() const;
+    const string& func() const      { return myfunc; }
+    // Associated glyphs in source and machine code
+    Widget& source_glyph() { return mysource_glyph; }
+    Widget& code_glyph()   { return mycode_glyph; }
+    friend class BreakPoint;
+};
+
 class BreakPoint {
     int     mynumber;		// Breakpoint number
     BPType  mytype;		// Type, as above
     BPDispo mydispo;		// Disposition, as above
     bool    myenabled;		// Is breakpoint enabled?
-    string  myfile_name;	// File name
-    int     myline_nr;		// Line number
-    string  myaddress;		// Address in memory
-    string  myfunc;		// Function name
+    std::vector<BreakPointLocn> locn;
     string  myexpr;		// Expression to watch (for watchpoints)
     string  myinfos;		// Additional information (human-readable)
     int     myignore_count;	// Ignore count
     string  mycondition;	// Breakpoint condition
-    StringArray mycommands;	// Commands to be issued when reached
+    std::vector<string> mycommands;	// Commands to be issued when reached
     string  myarg;		// Argument as given to breakpoint command
     WatchMode mywatch_mode;	// Watchpoint detail
 
@@ -94,9 +123,6 @@ class BreakPoint {
     bool    myaddress_changed;	// True if address changed
     bool    myselected;		// True if selected
 
-    Widget  mysource_glyph;	// Associated glyph in source
-    Widget  mycode_glyph;	// Associated glyph in code
-
 private:
     BreakPoint(const BreakPoint&);
     BreakPoint& operator = (const BreakPoint&);
@@ -141,15 +167,21 @@ public:
     // What to do when breakpoint is reached.
     BPDispo dispo() const { return mydispo; }
 
+    // Number of items (GDB has breakpoints at multiple locations)
+    int n_locations() const { return locn.size(); }
+
+    // Get numbered locn
+    BreakPointLocn &get_location(int i) { return locn[i]; }
+
     // Whether breakpoint is enabled
     bool enabled() const;
 
-    // Breakpoint position
-    const string& file_name() const { return myfile_name; }
-    int line_nr() const             { return myline_nr; }
-    const string& address() const   { return myaddress; }
+    // Breakpoint position (for simple breakpoints)
+    const string& file_name() const { return locn[0].myfile_name; }
+    int line_nr() const             { return locn[0].myline_nr; }
+    const string& address() const   { return locn[0].myaddress; }
     string pos() const;
-    const string& func() const      { return myfunc; }
+    const string& func() const      { return locn[0].myfunc; }
 
     // Watchpoint info
     const string& expr() const   { return myexpr; }
@@ -159,7 +191,7 @@ public:
     const string& infos() const          { return myinfos; }
     int ignore_count() const             { return myignore_count; }
     const string& real_condition() const { return mycondition; }
-    const StringArray& commands() const  { return mycommands; }
+    const std::vector<string>& commands() const  { return mycommands; }
     string condition() const;
 
     // Argument of breakpoint-setting command, as passed to constructor
@@ -168,10 +200,6 @@ public:
     // Selection state
     bool& selected() { return myselected; }
 
-    // Associated glyphs in source and machine code
-    Widget& source_glyph() { return mysource_glyph; }
-    Widget& code_glyph()   { return mycode_glyph; }
-
     // True iff `enabled' status changed
     bool enabled_changed () const { return myenabled_changed; }
 
