@@ -9,7 +9,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,8 +18,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -33,14 +32,14 @@
 // Create display boxes via the VSL library
 //-----------------------------------------------------------------------------
 
-#include "strclass.h"
-#include "Box.h"
-#include "ThemeVSLL.h"
-#include "VSLArgList.h"
-#include "DataLink.h"
+#include "base/strclass.h"
+#include "box/Box.h"
+#include "vslsrc/ThemeVSLL.h"
+#include "vslsrc/VSLArgList.h"
+#include "box/DataLink.h"
 #include "DispValue.h"
 #include "ThemeM.h"
-#include "assert.h"
+#include "base/assert.h"
 
 //-----------------------------------------------------------------------------
 
