@@ -41,13 +41,14 @@
 #ifndef _DDD_GDBAgent_h
 #define _DDD_GDBAgent_h
 
-#include "TTYAgent.h"
-#include "HandlerL.h"
-#include "strclass.h"
-#include "bool.h"
-#include "assert.h"
-#include "StringA.h"
-#include "VoidArray.h"
+#include "agent/TTYAgent.h"
+#include "agent/HandlerL.h"
+#include "base/strclass.h"
+#include "base/bool.h"
+#include "base/assert.h"
+#include "template/VoidArray.h"
+
+#include <vector>
 
 //-----------------------------------------------------------------------------
 // Debugger types
@@ -70,7 +71,7 @@ enum ProgramLanguage {
     LANGUAGE_CHILL,		// Chill, as supported by GDB.
     LANGUAGE_FORTRAN,		// FORTRAN, as supported by GDB.
     LANGUAGE_JAVA,		// Java, as supported by GDB.
-    LANGUAGE_MAKE,		// Make, as supported by mdb.
+    LANGUAGE_MAKE,		// Make, as supported by remake.
     LANGUAGE_PASCAL,		// Pascal-like: Pascal, Modula...
     LANGUAGE_PERL,		// Perl, as supported by Perl.
     LANGUAGE_PHP,		// PHP, as supported by DBG.
@@ -103,7 +104,7 @@ typedef void (* OAProc) (const string& answer,
 typedef void (* OACProc) (void* user_data);
 
 // Called from send_qu_array with the complete answers
-typedef void (* OQACProc) (StringArray& complete_answers,
+typedef void (* OQACProc) (std::vector<string>& complete_answers,
 			   const VoidArray& user_datas,
 			   void *user_data);
 
@@ -156,7 +157,6 @@ protected:
     };
     State state;		// Current state
 
-private:
     DebuggerType    _type;	// Debugger type
     void*           _user_data;	// used in callbacks etc.
 
@@ -164,9 +164,9 @@ private:
     bool _has_func_command;	
     bool _has_file_command;
     bool _has_run_io_command;
-    bool _has_print_r_option;
+    bool _has_print_r_option;	// FIXME:  Is this used?
     bool _has_output_command;
-    bool _has_where_h_option;
+    bool _has_where_h_option;	// FIXME:  Is this used?
     bool _has_display_command;
     bool _has_clear_command;
     bool _has_handler_command;
@@ -202,6 +202,7 @@ private:
 
     string last_prompt;		// Last prompt received
     string last_written;	// Last command sent
+    string _title;		// Name of debugger
     int echoed_characters;      // # of echoed characters so far (-1: no echo)
 
     bool exception_state;	// True if exception encountered
@@ -237,6 +238,11 @@ public:
 
     ~GDBAgent ();
 
+    static
+    GDBAgent* Create (XtAppContext app_context,
+	      const string& gdb_call,
+	      DebuggerType type);
+
     // Start new process
     void do_start (OAProc  on_answer,
 		   OACProc on_answer_completion,
@@ -247,7 +253,7 @@ public:
     void start_plus (OAProc   on_answer,
 		     OACProc  on_answer_completion,
 		     void*    user_data,
-		     const StringArray& cmds,
+		     const std::vector<string>& cmds,
 		     const VoidArray& user_datas,
 		     int      qu_count,
 		     OQACProc on_qu_array_completion,
@@ -268,7 +274,7 @@ public:
     // 3. Send CMDS, as in send_qu_array.
     // 4. When all replies have come in: call OACProc and OQACProc.
     //
-    bool send_user_cmd_plus (const StringArray& cmds,
+    bool send_user_cmd_plus (const std::vector<string>& cmds,
 			     const VoidArray& qu_datas,
 			     int      qu_count,
 			     OQACProc on_qu_array_completion,
@@ -277,7 +283,7 @@ public:
 			     string user_cmd,
 			     void* user_data = 0);
 
-    bool send_qu_array (const StringArray& cmds,
+    bool send_qu_array (const std::vector<string>& cmds,
 			const VoidArray& qu_datas,
 			int      qu_count,
 			OQACProc on_qu_array_completion,
@@ -294,7 +300,7 @@ public:
                                       return false;
 #endif
     }
-    const string& title()     const;
+    const string title()      const { return _title; }
     bool isReadyWithPrompt()  const { return state == ReadyWithPrompt; }
     const string& prompt()    const { return last_prompt; }
 
@@ -675,7 +681,10 @@ public:
     }
 
     // True if Ladebug
-    bool is_ladebug() const;
+    bool is_ladebug() const
+    {
+	return false;
+    }
 
     // True if a minimum indent is required.  This is true for
     // scripting languages.
@@ -711,63 +720,72 @@ public:
     // Several commands
 				                    // GDB command
 						    // -----------------------
-    string print_command(const char *expr = "",     // print|output EXP
-			 bool internal = true) const;
-    string print_command(const string& expr,
+    virtual string print_command(const char *expr = "",     // print|output EXP
+			 bool internal = true) const
+    {
+	/* UNUSED */ (void (expr));
+	/* UNUSED */ (void (internal));
+	assert (0);	/* Should never be called. */
+    }
+    virtual string print_command(const string& expr,
 			 bool internal = true) const {
       return print_command(expr.chars(), internal);
     }
-    string assign_command(const string& var,        // set variable VAR = EXPR
-			  const string& expr) const;
+    virtual string assign_command(const string& var,        // set variable VAR = EXPR
+			  const string& expr) const
+	{ /*UNUSED*/ (void (var)); (void (expr)); return ""; }
     string display_command(const char *expr = "") const; // display EXPR
     string display_command(const string& expr) const {
       return display_command(expr.chars());
     }
-    string where_command(int count = 0) const;	    // where COUNT
-    string pwd_command() const;	                    // pwd
-    string frame_command(int number) const;         // frame NUMBER
-    string relative_frame_command(int offset) const;// up|down OFFSET
-    string frame_command() const;                   // frame
-    string func_command() const;                    // func
-    string echo_command(const string& text) const;         // echo TEXT
-    string whatis_command(const string& expr) const;       // whatis EXPR
+    virtual string where_command(int count = 0) const;
+    virtual string pwd_command() const;	                    // pwd
+    virtual string frame_command(int num) const;
+    virtual string relative_frame_command(int offset) const;// up|down OFFSET
+    virtual string frame_command() const;	    // frame
+    virtual string func_command() const { return frame_command(); }
+    virtual string echo_command(const string& text) const;
+    virtual string whatis_command(const string& expr) const
+	{ /*UNUSED*/ (void (expr)); return ""; }
     string dereferenced_expr(const string& expr) const;    // *EXPR
     string address_expr(string expr) const;         // &EXPR
     string index_expr(const string& expr, const string& index) const; // EXPR[INDEX]
     int default_index_base() const;                 // 0 in C, else 1
     string member_separator() const;                // " = " in C
 
-    string info_locals_command() const;	            // info locals
-    string info_args_command() const;	            // info args
-    string info_display_command() const;	    // info display
+    virtual string info_locals_command() const { return "info locals"; }
+    virtual string info_args_command() const { return "info args"; }
+    virtual string info_display_command() const { return display_command(); }
     string disassemble_command(string start, const char *end = "") const;
                                                     // disassemble START END
     string disassemble_command(const string &start, const string& end ) const {
       return disassemble_command(start, end.chars() );
     }
-    string make_command(const string& target) const;       // make TARGET
-    string jump_command(const string& pc) const;    // jump PC
-    string regs_command(bool all = true) const;	    // info registers
-    string watch_command(const string& expr, WatchMode w = WATCH_CHANGE) const;
-				                    // watch EXPR
-    string kill_command() const;                    // kill
-    string enable_command(string bp = "") const;    // enable BP
-    string disable_command(string bp = "") const;   // disable BP
-    string delete_command(string bp = "") const;    // delete BP
-    string ignore_command(const string& bp, int count) const; 
-                                                    // ignore BP COUNT
-    string condition_command(const string& bp, const string& expr) const {
-      return condition_command(bp, expr.chars() );
-    }
-    string condition_command(const string& bp, const char *expr) const;
-				                    // cond BP EXPR
-    string shell_command(const string& cmd) const;	    // shell CMD
-    string debug_command(const char *file = "",          // file FILE
-			 string args = "") const;
-    string debug_command(const string& file, string args = "") const {
+    virtual string make_command(const string& args) const { /*UNUSED*/ (void (args)); return ""; }
+    virtual string jump_command(const string& pc) const { /*UNUSED*/ (void (pc)); return ""; }
+    virtual string regs_command(bool all = true) const { /*UNUSED*/ (void (all)); return ""; }
+    virtual string watch_command(const string& expr, WatchMode w = WATCH_CHANGE) const {
+	/*UNUSED*/ (void (expr)); (void (w)); return "";
+    } // watch EXPR
+    virtual string kill_command() const { return "kill"; }                    // kill
+    virtual string enable_command(string bp = "") const { /*UNUSED*/ (void (bp)); return ""; }
+    virtual string disable_command(string bp = "") const { /*UNUSED*/ (void (bp)); return ""; }
+    virtual string delete_command(string bp = "") const { /*UNUSED*/ (void (bp)); return ""; }
+    virtual string ignore_command(const string& bp, int count) const
+	{ /*UNUSED*/ (void (bp)); (void (count)); return ""; }
+    virtual string condition_command(const string& bp, const string& expr) const
+	{ return condition_command(bp, expr.chars() ); }
+    virtual string condition_command(const string& bp, const char *expr) const
+	{ /*UNUSED*/ (void (bp)); (void (expr)); return ""; }
+    virtual string shell_command(const string& cmd) const
+	{ return "shell " + cmd; }
+    virtual string debug_command(const char *file = "",          // file FILE
+			 string args = "") const
+	{ /*UNUSED*/ (void (file)); (void (args)); return ""; }
+    virtual string debug_command(const string& file, string args = "") const {
       return debug_command( file.chars(), args );
     }
-    string signal_command(int sig) const;           // signal SIG
+    virtual string signal_command(int sig) const { /*UNUSED*/ (void (sig)); return ""; }
     string nop_command(const char *comment = "") const;  // # comment
     string nop_command(const string& comment) const {
       return nop_command(comment.chars());
@@ -781,17 +799,20 @@ public:
 			       string& prefix, string& package, string& name);
 
     // Run program with given arguments
-    string run_command(string args) const;	    // set args ARGS\nrun
+    virtual string run_command(string args) const 
+	{ return "run" + args; }
 
     // Run program, re-using current arguments
-    string rerun_command() const;                   // run
+    virtual string rerun_command() const { return "run"; }
 
     // Attach to process id PID
-    string attach_command(int pid, const string& file) const;  // attach PID
-    string detach_command(int pid) const;                      // detach
+    virtual string attach_command(int pid, const string& file) const
+	{ /*UNUSED*/ (void (pid)); (void (file)); return ""; }
+    virtual string detach_command(int pid) const                
+	{ /*UNUSED*/ (void (pid)); return ""; }
 
     // Default history file
-    string history_file() const;                    // GDB: ~/.gdb_history
+    virtual string history_file() const { return ""; }
 
     // Send DATA to process
     virtual int write(const char *data, int length);
@@ -803,15 +824,27 @@ public:
     }
 
     // Write a command (not debuggee interaction or control characters)
-    int write_cmd(const string& cmd);
+    virtual int write_cmd(const string& cmd) { return write(cmd); }
 
     // True if ANSWER ends in a prompt
-    bool ends_with_prompt(const string& answer);
-    bool ends_with_secondary_prompt(const string& answer) const;
+    virtual bool ends_with_prompt(const string& answer);
+    virtual bool ends_with_secondary_prompt(const string& answer) const
+    { 
+	/* Unused */ (void (answer));
+	return false;
+    }
+    virtual void cut_off_prompt(string& answer) const
+    { 
+	/* Unused */ (void (answer));
+    }
     bool ends_with_yn(const string& answer) const;
 
     // True if exception error message
-    bool is_exception_answer(const string& answer) const;
+    virtual bool is_exception_answer(const string& answer) const
+    { 
+	/* Unused */ (void (answer));
+	return false;
+    }
     void set_exception_state(bool state);
 
     // Helpers
@@ -827,8 +860,8 @@ private:
 
     int     qu_index;
     int    _qu_count;
-    StringArray cmd_array;
-    StringArray complete_answers;
+    std::vector<string> cmd_array;
+    std::vector<string> complete_answers;
     VoidArray _qu_datas;
     void*   _qa_data;
 
@@ -836,7 +869,7 @@ private:
     OACProc  _on_answer_completion;
     OQACProc _on_qu_array_completion;
 
-    void    init_qu_array (const StringArray& cmds,
+    void    init_qu_array (const std::vector<string>& cmds,
 			   const VoidArray& qu_datas,
 			   int      qu_count,
 			   OQACProc on_qu_array_completion,
@@ -844,9 +877,7 @@ private:
 
     string requires_reply(const string& answer);
 
-    void cut_off_prompt(string& answer) const;
     void strip_dbx_comments(string& answer) const;
-    void strip_control(string& answer) const;
 
     void normalize_answer(string& answer) const;
     void normalize_address(string& addr) const;
@@ -859,6 +890,7 @@ private:
 
 protected:
     string complete_answer;
+    void strip_control(string& answer) const;
 
     static void InputHP  (Agent *, void *, void *);
     static void PanicHP  (Agent *, void *, void *);
