@@ -2,6 +2,7 @@
 // View the Source.
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 2004 Free Software Foundation, Inc.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>
 // and Andreas Zeller <zeller@gnu.org>.
 // 
@@ -10,7 +11,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,8 +20,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -47,25 +47,27 @@
 #ifndef _DDD_SourceView_h
 #define _DDD_SourceView_h
 
+#include <vector>
+
 // Motif includes
 #include <Xm/Xm.h>
 
 // Misc includes
-#include "strclass.h"
-#include "Assoc.h"
-#include "MakeMenu.h"
-#include "StringA.h"
-#include "IntIntAA.h"
-#include "TextPosA.h"
+#include "base/strclass.h"
+#include "template/Assoc.h"
+#include "motif/MakeMenu.h"
+#include "template/IntIntAA.h"
 
 // DDD includes
 #include "ArgField.h"
 #include "GDBAgent.h"
-#include "BreakPM.h"
+#include "template/Map.h"
+#include "BreakPoint.h"
 #include "CodeCache.h"
-#include "Delay.h"
-#include "StringSA.h"
-#include "MString.h"
+#include "x11/Delay.h"
+#include "template/StringSA.h"
+#include "motif/MString.h"
+#include "SourceCode.h"
 
 //-----------------------------------------------------------------------------
 extern GDBAgent* gdb;
@@ -155,8 +157,8 @@ class SourceView {
 
     // Create text or code widget
     static void create_text(Widget parent,
-			    const char *base, bool editable,
-			    Widget& form, Widget& text);
+                            const char *base, bool editable,
+                            Widget& form, Widget& text);
 
     // Refresh displays
     static void refresh_bp_disp(bool reset = false);
@@ -169,16 +171,16 @@ class SourceView {
 
     // Move/Copy breakpoint NR to ADDRESS; return true if changed
     static bool move_bp(int nr, const string& address, Widget origin = 0,
-			bool copy = false);
+                        bool copy = false);
     static bool copy_bp(int nr, const string& address, Widget origin = 0)
     {
-	return move_bp(nr, address, origin, true);
+        return move_bp(nr, address, origin, true);
     }
 
     // Position history
     static void add_current_to_history();
     static void add_position_to_history(const string& file_name, 
-					int line, bool stopped);
+                                        int line, bool stopped);
 
     // Set condition of breakpoints NRS to COND.
     // * If COND is char(-1), preserve old condition.
@@ -187,31 +189,31 @@ class SourceView {
     // * If MAKE_FALSE is == 0, enable breakpoint by restoring
     //   the original condition.
     // * Otherwise, preserve the condition state.
-    static void _set_bps_cond(const IntArray& nrs, const string& cond, 
-			      int make_false, Widget origin);
+    static void _set_bps_cond(const std::vector<int>& nrs, const string& cond,
+                              int make_false, Widget origin);
 
     // Set condition of breakpoints NRS to COND.
-    inline static void set_bps_cond(const IntArray& nrs, const string& cond,
-				    Widget origin = 0)
+    inline static void set_bps_cond(const std::vector<int>& nrs, const string& cond,
+                                    Widget origin = 0)
     {
-	_set_bps_cond(nrs, cond, -1, origin);
+        _set_bps_cond(nrs, cond, -1, origin);
     }
 
     // Enable and disable breakpoints via conditions.
-    inline static void set_bps_cond_enabled(const IntArray& nrs, bool enabled,
-					    Widget origin = 0)
+    inline static void set_bps_cond_enabled(const std::vector<int>& nrs, bool enabled,
+                                            Widget origin = 0)
     {
-	_set_bps_cond(nrs, char(-1), enabled ? 0 : 1, origin);
+        _set_bps_cond(nrs, char(-1), enabled ? 0 : 1, origin);
     }
 
     // Custom calls
-    inline static void enable_bps_cond(const IntArray& nrs, Widget origin = 0)
+    inline static void enable_bps_cond(const std::vector<int>& nrs, Widget origin = 0)
     {
-	set_bps_cond_enabled(nrs, true, origin);
+        set_bps_cond_enabled(nrs, true, origin);
     }
-    inline static void disable_bps_cond(const IntArray& nrs, Widget origin = 0)
+    inline static void disable_bps_cond(const std::vector<int>& nrs, Widget origin = 0)
     {
-	set_bps_cond_enabled(nrs, false, origin);
+        set_bps_cond_enabled(nrs, false, origin);
     }
 
     // Find the line number at POS.  LINE_NR becomes the line number
@@ -219,18 +221,18 @@ class SourceView {
     // BP_NR is the number of the breakpoint at POS (none: 0).  Return
     // false iff failure.
     static bool get_line_of_pos (Widget w,
-				 XmTextPosition pos,
-				 int& line_nr,
-				 string& address,
-				 bool& in_text,
-				 int& bp_nr);
+                                 XmTextPosition pos,
+                                 int& line_nr,
+                                 string& address,
+                                 bool& in_text,
+                                 int& bp_nr);
 
     // Find word around POS.  STARTPOS is the first character, ENDPOS
     // is the last character in the word.
     static void find_word_bounds (Widget w,
-				  const XmTextPosition pos,
-				  XmTextPosition& startpos,
-				  XmTextPosition& endpos);
+                                  const XmTextPosition pos,
+                                  XmTextPosition& startpos,
+                                  XmTextPosition& endpos);
 
     //-----------------------------------------------------------------------
     // Action procedures
@@ -266,14 +268,13 @@ class SourceView {
     static MMDesc bp_area[];
 
     static void set_text_popup_label(int item, const string& arg, bool sens);
-    static void set_text_popup_resource(int item, const string& arg);
 
     //-----------------------------------------------------------------------
     // Data
     //-----------------------------------------------------------------------
-    static bool checking_scroll;
+    //static bool checking_scroll;
 
-    static Widget toplevel_w;	 // Top-level widget
+    static Widget toplevel_w;         // Top-level widget
 
     static Widget source_form_w; // Form around text and glyphs
     static Widget source_text_w; // Source text
@@ -287,7 +288,7 @@ class SourceView {
     static Widget frame_list_w;              // The frame list
     static Widget up_w;                      // The `Up' button
     static Widget down_w;                    // The `Down' button
-    static bool stack_dialog_popped_up;	     // True if the stack is visible
+    static bool stack_dialog_popped_up;             // True if the stack is visible
 
     static Widget register_dialog_w;          // Dialog for registers
     static Widget register_list_w;            // Register list inside
@@ -299,29 +300,22 @@ class SourceView {
     static Widget thread_list_w;              // Thread list inside
     static bool thread_dialog_popped_up;      // True if registers are visible
 
-    static bool display_glyphs;	              // Display glyphs?
-    static bool display_line_numbers;	      // Display line numbers?
+    static bool display_glyphs;                      // Display glyphs?
+//     static bool display_line_numbers;              // Display line numbers?
     
-    static bool disassemble;	              // Disassemble code?
-    static bool all_registers;	              // Show all registers?
+    static bool disassemble;                      // Disassemble code?
+    static bool all_registers;                      // Show all registers?
     static bool at_lowest_frame;              // Are we at lowest frame?
-    static bool signal_received;	      // Did we receive a signal?
+    static bool signal_received;              // Did we receive a signal?
 
     static WatchMode selected_watch_mode;     // Last selected watch mode
 
-    // Tab width
-    static int tab_width;
-
     // The breakpoint map
-    static BreakPointMap bp_map;
+    static Map<int, BreakPoint> bp_map;
 
     // File attributes
-    static string current_file_name;
-    static int    line_count;
-    static IntIntArrayAssoc bps_in_line;
-    static TextPositionArray _pos_of_line;
-    static StringArray bp_addresses;
-    static XmTextPosition pos_of_line(int line);
+    static IntIntArrayAssoc bps_in_line;  // non-glyph breakpoints in current source
+    static std::vector<string> bp_addresses; // breakpoint addresses in current code
 
     // True iff breakpoint BP is in current file (at LINE, if given)
     static bool bp_matches(BreakPoint *bp, int line = 0);
@@ -329,6 +323,12 @@ class SourceView {
     // True iff breakpoint BP is in FILE (at LINE, if given)
     static bool bp_matches(BreakPoint *bp, const string& file, int line = 0);
 
+    // True iff breakpoint location locn is in current file (at LINE, if given)
+    static bool bp_matches(BreakPointLocn &locn, int line = 0);
+
+    // True iff breakpoint location locn is in FILE (at LINE, if given)
+    static bool bp_matches(BreakPointLocn &locn, const string& file, int line = 0);
+
     // True iff FILE1 is equal to FILE2
     static bool file_matches(const string& file1, const string& file2);
 
@@ -338,41 +338,19 @@ class SourceView {
     // True iff FILE is the currently loaded file
     static bool is_current_file(const string& file);
 
-    static StringStringAssoc file_cache;
-    static StringOriginAssoc origin_cache;
     static CodeCache code_cache;
 
     // The current source text.
-    static string current_source;
+    static SourceCode sourcecode;
 
     // The current frame number.  (-1 if none)
     static int current_frame;
 
-    // The origin of the current source text.
-    static SourceOrigin current_origin;
-
     // The current assembler code.
     static string current_code;
     static string current_code_start;
     static string current_code_end;
 
-    // Return current source name (name under this source is known to GDB)
-    static StringStringAssoc source_name_cache;
-    static string current_source_name();
-
-    // File name of current source (for JDB)
-    static StringStringAssoc file_name_cache;
-
-    // Files listed as erroneous
-    static StringArray bad_files;
-    static bool new_bad_file(const string& file_name);
-    static void post_file_error(const string& file_name,
-				const string& text, const _XtString name = 0,
-				Widget origin = 0);
-    static void post_file_warning(const string& file_name,
-				  const string& text, const _XtString name = 0,
-				  Widget origin = 0);
-
     // The current directory
     static string current_pwd;
 
@@ -387,6 +365,8 @@ class SourceView {
     static XmTextPosition last_pos;
     static XmTextPosition last_start_highlight;
     static XmTextPosition last_end_highlight;
+    static Position last_x;
+    static Position last_y;
 
     // Some positions in assembler code.
     static XmTextPosition last_top_pc;
@@ -399,45 +379,27 @@ class SourceView {
     static string last_execution_pc;
     static string last_shown_pc;
     static void _show_execution_position (const string& file, int line, 
-					  bool silent, bool stopped);
+                                          bool silent, bool stopped);
 
     // Last frame position
     static int last_frame_pos;
     static bool frame_pos_locked;
 
-    // Read source text
-    static String read_local(const string& file_name, long& length,
-			     bool silent);
-    static String read_remote(const string& file_name, long& length,
-			      bool silent);
-    static String read_class(const string& class_name, 
-			     string& file_name, SourceOrigin& origin,
-			     long& length, bool silent);
-    static String read_from_gdb(const string& source_name, long& length,
-				bool silent);
-
-    static String read_indented(string& file_name, long& length,
-				SourceOrigin& origin,
-				bool silent = false);
-    static int read_current(string& file_name, 
-			    bool force_reload = false,
-			    bool silent = false);
-
     // Set insertion position to POS.
     static void SetInsertionPosition(Widget w, XmTextPosition pos, 
-				     bool fromTop = false);
+                                     bool fromTop = false);
 
     // Make position POS visible.
     static void ShowPosition(Widget w, XmTextPosition pos, 
-			     bool fromTop = false);
+                             bool fromTop = false);
 
     static bool is_source_widget(Widget w);
     static bool is_code_widget(Widget w);
-    static string& current_text(Widget w);
 
     // Return current breakpoint indent amount.  If POS is given, add
     // the whitespace from POS.
     static int indent_amount(Widget w, int pos = -1);
+    static int indent_amount_code(int pos = -1);
 
     // Format `where' and `thread' lines
     static void setup_where_line(string& line);
@@ -446,8 +408,8 @@ class SourceView {
     static XmTextPosition find_pc(const string& pc);
     static void refresh_codeOQC(const string& answer, void *data);
     static void set_code(const string& code,
-			 const string& start,
-			 const string& end);
+                         const string& start,
+                         const string& end);
 
     static MString help_on_bp(int bp, bool detailed);
 
@@ -479,7 +441,7 @@ class SourceView {
 
     // Create glyph in FORM_W named NAME from given BITS
     static Widget create_glyph(Widget form_w, const _XtString name, 
-			       unsigned char *bits, int width, int height);
+                               unsigned char *bits, int width, int height);
 
     // Map glyph W in (X, Y)
     static void map_glyph(Widget& w, Position x, Position y);
@@ -493,7 +455,7 @@ class SourceView {
 
     // Return position during glyph drag and drop
     static XmTextPosition glyph_position(Widget w, XEvent *e, 
-					 bool normalize = true);
+                                         bool normalize = true);
 
     // Get relative coordinates of GLYPH in TEXT
     static void translate_glyph_pos(Widget glyph, Widget text, int& x, int& y);
@@ -522,40 +484,43 @@ private:
     static Widget past_arrows[2];
     static Widget signal_arrows[2];
     static Widget drag_arrows[2];
-    static WidgetArray plain_stops[2];
-    static WidgetArray grey_stops[2];
-    static WidgetArray plain_conds[2];
-    static WidgetArray grey_conds[2];
-    static WidgetArray plain_temps[2];
-    static WidgetArray grey_temps[2];
+    static std::vector<Widget> plain_stops[2];
+    static std::vector<Widget> grey_stops[2];
+    static std::vector<Widget> multi_stops[2];
+    static std::vector<Widget> plain_conds[2];
+    static std::vector<Widget> grey_conds[2];
+    static std::vector<Widget> multi_conds[2];
+    static std::vector<Widget> plain_temps[2];
+    static std::vector<Widget> grey_temps[2];
+    static std::vector<Widget> multi_temps[2];
     static Widget drag_stops[2];
     static Widget drag_conds[2];
     static Widget drag_temps[2];
 
     // Return position POS of glyph GLYPH in X/Y.  Return true iff displayed.
     static bool glyph_pos_to_xy(Widget glyph, XmTextPosition pos,
-				Position& x, Position& y);
+                                Position& x, Position& y);
 
     // Map stop sign in W at position POS.  Get widget from STOPS[COUNT];
     // store location in POSITIONS.  Return mapped widget (0 if none)
     static Widget map_stop_at(Widget w, XmTextPosition pos,
-			      WidgetArray& stops, int& count,
-			      TextPositionArray& positions);
+                              WidgetArray& stops, int& count,
+                              std::vector<XmTextPosition>& positions);
 
     // Map arrow/drag arrow/drag stop in W at POS.  If ORIGIN is
     // given, use colors from ORIGIN.
     static Widget map_arrow_at     (Widget w, XmTextPosition pos);
     static Widget map_drag_arrow_at(Widget w, XmTextPosition pos,
-				    Widget origin = 0);
+                                    Widget origin = 0);
     static inline void unmap_drag_arrow(Widget w)
     {
-	map_drag_arrow_at(w, XmTextPosition(-1));
+        map_drag_arrow_at(w, XmTextPosition(-1));
     }
     static Widget map_drag_stop_at (Widget w, XmTextPosition pos,
-				    Widget origin = 0);
+                                    Widget origin = 0);
     static inline void unmap_drag_stop(Widget w)
     {
-	map_drag_stop_at(w, XmTextPosition(-1));
+        map_drag_stop_at(w, XmTextPosition(-1));
     }
     static void copy_colors(Widget w, Widget origin);
 
@@ -586,7 +551,7 @@ private:
     static int breakpoint_number(const string& bp_info, string& file);
 
     // Get numbers of selected breakpoints
-    static void getBreakpointNumbers(IntArray& numbers);
+    static void getBreakpointNumbers(std::vector<int>& numbers);
 
 public:
     // Constructor
@@ -600,9 +565,9 @@ public:
     // STOPPED indicates that the program just stopped.
     // SIGNALED indicates that the program received a signal.
     static void show_execution_position (const string& position = "",
-					 bool stopped    = false,
-					 bool signaled   = false,
-					 bool silent     = false);
+                                         bool stopped    = false,
+                                         bool signaled   = false,
+                                         bool silent     = false);
 
     // Unset current execution position (program terminated)
     static void clear_execution_position();
@@ -615,13 +580,13 @@ public:
     // STOPPED indicates that the program just stopped.
     // SIGNALED indicates that the program just received a signal.
     static void show_pc (const string& pc, 
-			 XmHighlightMode mode = XmHIGHLIGHT_NORMAL,
-			 bool stopped  = false,
-			 bool signaled = false);
+                         XmHighlightMode mode = XmHIGHLIGHT_NORMAL,
+                         bool stopped  = false,
+                         bool signaled = false);
 
     // Handle breakpoint information
     static void process_info_bp         (string& info_output,
-					 const string& break_arg = "");
+                                         const string& break_arg = "");
 
     // Handle 'info line' information
     static void process_info_line_main  (string& info_output);
@@ -664,19 +629,19 @@ public:
     enum SearchDirection {forward, backward};
 
     static void find(const string& s,
-		     SearchDirection direction = forward,
-		     bool words_only = false,
-		     bool case_sensitive = false,
-		     Time time = CurrentTime);
+                     SearchDirection direction = forward,
+                     bool words_only = false,
+                     bool case_sensitive = false,
+                     Time time = CurrentTime);
 
     // Locate function S; if S is omitted, locate last execution position.
     static void lookup(string s, bool silent = false);
 
     // Read file FILE_NAME; place cursor at INITIAL_LINE.
     static void read_file(string file_name,
-			  int initial_line = 1,
-			  bool force_reload = false,
-			  bool silent = false);
+                          int initial_line = 1,
+                          bool force_reload = false,
+                          bool silent = false);
 
     // Reload current file
     static void reload();
@@ -711,8 +676,18 @@ public:
     static bool can_go_down();
 
     // Check whether source files and code are to be cached
-    static bool cache_source_files;
     static bool cache_machine_code;
+    static void set_cache_machine_code(bool set)
+    {
+        if (set == cache_machine_code)
+            return;
+
+        cache_machine_code = set;
+        if (!cache_machine_code)
+            clear_code_cache();
+    }
+
+    static void set_cache_source(bool set) { sourcecode.set_caches(set); }
 
     // Set whether glyphs are to be displayed
     static void set_display_glyphs(bool value);
@@ -730,7 +705,7 @@ public:
     static void set_tab_width(int width);
 
     // Set the indentation
-    static void set_indent(int source_indent, int code_indent);
+    static void set_indent(int source_indent, int code_indent, int script_indent);
 
     // Set the max number of glyphs
     static void set_max_glyphs(int max_glyphs);
@@ -742,10 +717,7 @@ public:
     static int max_popup_expr_length;
 
     // The indenting amounts
-    static int source_indent_amount;         // Source
     static int code_indent_amount;           // Machine code
-    static int line_indent_amount;           // Extra columns for line numbers
-    static int script_indent_amount;         // Minimum for scripts
 
     // The scrolling amounts
     static int lines_above_cursor;           // Lines to keep before cursor
@@ -762,7 +734,7 @@ public:
     // breakpoint temporary.  If COND is given, break only iff COND
     // evals to true.  ORIGIN is the origin.
     static void set_bp(const string& a, bool set, bool temp, 
-		       const char *cond = "", Widget origin = 0);
+                       const char *cond = "", Widget origin = 0);
 
     // Custom calls
     static void create_bp(const string& a, Widget origin = 0);
@@ -773,54 +745,54 @@ public:
     static void temp_n_cont(const string& a, Widget origin = 0);
 
     // Enable/Disable/Delete/Edit breakpoints
-    static void enable_bps     (const IntArray& nrs, Widget origin = 0);
-    static void disable_bps    (const IntArray& nrs, Widget origin = 0);
-    static void delete_bps     (const IntArray& nrs, Widget origin = 0);
-    static void edit_bps       (IntArray& nrs, Widget origin = 0);
+    static void enable_bps     (const std::vector<int>& nrs, Widget origin = 0);
+    static void disable_bps    (const std::vector<int>& nrs, Widget origin = 0);
+    static void delete_bps     (const std::vector<int>& nrs, Widget origin = 0);
+    static void edit_bps       (std::vector<int>& nrs, Widget origin = 0);
 
     inline static void enable_bp(int nr, Widget origin = 0)
     {
-	IntArray nrs;
-	nrs += nr;
-	enable_bps(nrs, origin);
+        std::vector<int> nrs;
+        nrs.push_back(nr);
+        enable_bps(nrs, origin);
     }
 
     inline static void disable_bp(int nr, Widget origin = 0)
     {
-	IntArray nrs;
-	nrs += nr;
-	disable_bps(nrs, origin);
+        std::vector<int> nrs;
+        nrs.push_back(nr);
+        disable_bps(nrs, origin);
     }
 
     inline static void delete_bp(int nr, Widget origin = 0)
     {
-	IntArray nrs;
-	nrs += nr;
-	delete_bps(nrs, origin);
+        std::vector<int> nrs;
+        nrs.push_back(nr);
+        delete_bps(nrs, origin);
     }
 
     inline static void edit_bp(int nr, Widget origin = 0)
     {
-	IntArray nrs;
-	nrs += nr;
-	edit_bps(nrs, origin);
+        std::vector<int> nrs;
+        nrs.push_back(nr);
+        edit_bps(nrs, origin);
     }
 
     // Set breakpoint commands
-    static void set_bp_commands(IntArray& nrs, const StringArray& commands,
-				Widget origin = 0);
-    inline static void set_bp_commands(int nr, const StringArray& commands,
-				       Widget origin = 0)
+    static void set_bp_commands(std::vector<int>& nrs, const std::vector<string>& commands,
+                                Widget origin = 0);
+    inline static void set_bp_commands(int nr, const std::vector<string>& commands,
+                                       Widget origin = 0)
     {
-	IntArray nrs;
-	nrs += nr;
-	set_bp_commands(nrs, commands, origin);
+        std::vector<int> nrs;
+        nrs.push_back(nr);
+        set_bp_commands(nrs, commands, origin);
     }
 
-    static string numbers(const IntArray& nrs);
-    static string all_numbers(const IntArray& nrs);
-    static bool all_bps(const IntArray& nrs);
-	    
+    static string numbers(const std::vector<int>& nrs);
+    static string all_numbers(const std::vector<int>& nrs);
+    static bool all_bps(const std::vector<int>& nrs);
+            
     // Move PC to ADDRESS; return true if changed.
     static bool move_pc(const string& address, Widget origin = 0);
 
@@ -828,9 +800,9 @@ public:
     // guess the next event number and clear this one as well.
     // Consider only breakpoints whose number is >= FIRST_BP.
     static string clear_command(string arg, bool clear_next = false,
-				int first_bp = 0);
+                                int first_bp = 0);
     // Return `delete N' command.
-    static string delete_command(int bp_nr);
+    static std::vector<string> delete_commands(int bp_nr);
 
     // Return `{ COMMAND; }'
     static string command_list(const string& cmd);
@@ -842,7 +814,7 @@ public:
     static string class_path();
 
     // Return current source file name
-    static string name_of_source() { return current_source_name(); }
+    static string name_of_source() { return sourcecode.current_source_name(); }
 
     // Return source text and machine code widget (read-only)
     static Widget source() { return source_text_w; }
@@ -853,7 +825,8 @@ public:
     static Widget code_form()   { return code_form_w; }
 
     // Clear caches
-    static void clear_file_cache();
+    static void clear_file_cache() {
+        sourcecode.clear_file_cache(); }
     static void clear_code_cache();
 
     // Get the line at POSITION
@@ -862,7 +835,7 @@ public:
     // Get a help string for GLYPH; return 0 if none
     static MString help_on_glyph(Widget glyph, bool detailed);
     static MString help_on_pos(Widget w, XmTextPosition pos, 
-			       XmTextPosition& ref, bool detailed);
+                               XmTextPosition& ref, bool detailed);
 
     // Get the position of breakpoint NUM
     static string bp_pos(int num);
@@ -875,20 +848,20 @@ public:
 
     // Get the word at position of EVENT
     static string get_word_at_event(Widget w,
-				    XEvent *event,
-				    XmTextPosition& first_pos,
-				    XmTextPosition& last_pos);
+                                    XEvent *event,
+                                    XmTextPosition& first_pos,
+                                    XmTextPosition& last_pos);
 
     // Get the word at position POS
     static string get_word_at_pos(Widget w,
-				  XmTextPosition pos,
-				  XmTextPosition& startpos,
-				  XmTextPosition& endpos);
+                                  XmTextPosition pos,
+                                  XmTextPosition& startpos,
+                                  XmTextPosition& endpos);
 
     // Examine DDD state
 
     // True iff we have some source text
-    static bool have_source() { return current_source.length() != 0; }
+    static bool have_source() { return sourcecode.have_source(); }
 
     // True iff we have some execution position
     static bool have_exec_pos() { return !last_execution_file.empty(); }
@@ -922,7 +895,7 @@ public:
 
     // Goto history entry
     static void goto_entry(const string& file, int line,
-			   const string& address, bool exec_pos);
+                           const string& address, bool exec_pos);
 
     // Set or unset showing earlier state
     static void showing_earlier_state(bool set);
