@@ -28,9 +28,9 @@
 #ifndef _DDD_UndoBufferEntry_h
 #define _DDD_UndoBufferEntry_h
 
-#include "StringSA.h"
-#include "VarArray.h"
-#include "bool.h"
+#include "template/StringSA.h"
+#include <vector>
+#include "base/bool.h"
 
 // Special value keys
 #define UB_POS           "pos"	        // Current source position
@@ -94,7 +94,7 @@ public:
     int allocation() const;
 };
 
-typedef VarArray<UndoBufferEntry> UndoBufferArray;
+typedef std::vector<UndoBufferEntry> UndoBufferArray;
 
 #endif // _DDD_UndoBufferEntry_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
