@@ -9,7 +9,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,8 +18,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -29,8 +28,11 @@
 #ifndef _DDD_fonts_h
 #define _DDD_fonts_h
 
-#include "strclass.h"
+#include "base/strclass.h"
 #include "AppData.h"
+#include "motif/MakeMenu.h"
+
+#include <vector>
 
 #include <X11/Intrinsic.h>
 
@@ -38,7 +40,6 @@
 enum DDDFont { DefaultDDDFont       = 0,
 	       VariableWidthDDDFont = 1,
 	       FixedWidthDDDFont    = 2,
-	       SymbolDDDFont        = 3,
                DataDDDFont          = 4 };
 
 // Setup font specs.  DB is the resource database in use.
@@ -50,9 +51,14 @@ extern void setup_fonts(AppData& app_data, XrmDatabase db = 0);
 extern string make_font(const AppData& ad, DDDFont base, 
 			const string& override = "");
 
+extern string make_xftfont(const AppData& ad, DDDFont base);
+
 // Set a new font resource
 extern void set_font(DDDFont n, const string& name);
 
+std::vector<string> GetFixedWithFonts();
+std::vector<string> GetVariableWithFonts();
+
 // Browse fonts
 extern void BrowseFontCB(Widget w, XtPointer, XtPointer);
 
