@@ -9,7 +9,7 @@
 // DDD is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// version 3 of the License, or (at your option) any later version.
 // 
 // DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,8 +18,7 @@
 // 
 // You should have received a copy of the GNU General Public
 // License along with DDD -- see the file COPYING.
-// If not, write to the Free Software Foundation, Inc.,
-// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// If not, see <http://www.gnu.org/licenses/>.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
@@ -29,13 +28,13 @@
 #ifndef _DDD_history_h
 #define _DDD_history_h
 
-#include "strclass.h"
-#include "bool.h"
-#include "StringA.h"
+#include "base/strclass.h"
+#include "base/bool.h"
 #include "HistoryF.h"
 
 #include <X11/Intrinsic.h>
 
+#include <vector>
 
 // History management
 extern void process_history_filename(string answer);
@@ -80,10 +79,10 @@ extern void tie_combo_box_to_history(Widget text, HistoryFilter filter);
 extern void add_to_recent(const string& file);
 
 // Get recent file history (most recent first)
-extern void get_recent(StringArray& arr);
+extern void get_recent(std::vector<string>& arr);
 
 // Tie a menu to recent files
-class MMDesc;
+struct MMDesc;
 extern void tie_menu_to_recent_files(MMDesc *items);
 
 #endif // _DDD_history_h
